@@ -1,12 +1,10 @@
-import warnings
-
 from django.core.urlresolvers import resolve, reverse
 from django.test import TestCase
 
 
 class URLTestMixin(object):
     def assert_url_matches_view(self, view, expected_url, url_name,
-                                url_args=None, url_kwargs=None):
+                                url_args=None, url_kwargs=None, urlconf=None):
         """
         Assert a view's url is correctly configured
 
@@ -14,10 +12,10 @@ class URLTestMixin(object):
         Check the expected_url resolves to the expected view.
         """
 
-        reversed_url = reverse(url_name, args=url_args, kwargs=url_kwargs)
+        reversed_url = reverse(url_name, urlconf=urlconf, args=url_args, kwargs=url_kwargs)
         self.assertEqual(reversed_url, expected_url)
 
-        resolved_view = resolve(expected_url).func
+        resolved_view = resolve(expected_url, urlconf=urlconf).func
 
         if hasattr(resolved_view, 'cls'):
             self.assertEqual(resolved_view.cls, view)
